@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from uuid_generator import generate_uuid
+from semantyk.uuid_generator import generate_uuid
 from rdflib import Literal, URIRef
 
 class Graph(object):
