@@ -9,7 +9,7 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from namespace.namespace import RDF, RDFS, SMTK
+from semantyk.namespace.namespace import RDF, RDFS, SMTK
 from rdflib import Namespace, URIRef
 
 class Resource(object):
